@@ -12,6 +12,11 @@ from dataverk_airflow.init_containers import create_git_clone_init_container, db
 from dataverk_airflow.notifications import create_email_notification, create_slack_notification
 
 
+POD_WORKSPACE_DIR = "/workspace"
+CA_BUNDLE_PATH = "/etc/pki/tls/certs/ca-bundle.crt"
+CREDS_DIR = "/var/run/secrets"
+
+
 def create_knada_nb_pod_operator(
     dag: DAG,
     name: str,
@@ -51,7 +56,7 @@ def create_knada_nb_pod_operator(
 
     env_vars = {
         "LOG_ENABLED": "true" if log_output else "false",
-        "NOTEBOOK_PATH": f"/repo/{Path(nb_path).parent}",
+        "NOTEBOOK_PATH": f"{POD_WORKSPACE_DIR}/{Path(nb_path).parent}",
         "NOTEBOOK_NAME": Path(nb_path).name,
         "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
         "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
@@ -63,7 +68,7 @@ def create_knada_nb_pod_operator(
         "VKS_AUTH_PATH": os.environ["VKS_AUTH_PATH"],
         "VKS_KV_PATH": os.environ["VKS_KV_PATH"],
         "K8S_SERVICEACCOUNT_PATH": os.environ["K8S_SERVICEACCOUNT_PATH"],
-        "REQUESTS_CA_BUNDLE": "/etc/pki/tls/certs/ca-bundle.crt"
+        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH
     }
 
     if extra_envs:
@@ -79,7 +84,7 @@ def create_knada_nb_pod_operator(
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
-        init_containers=[create_git_clone_init_container(repo, branch, "/repo")],
+        init_containers=[create_git_clone_init_container(repo, branch, POD_WORKSPACE_DIR)],
         dag=dag,
         on_failure_callback=on_failure,
         name=name,
@@ -91,11 +96,11 @@ def create_knada_nb_pod_operator(
         env_vars=env_vars,
         volume_mounts=[
             VolumeMount(
-                name="dags-data", mount_path="/repo", sub_path=None, read_only=False
+                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
             ),
             VolumeMount(
                 name="ca-bundle-pem",
-                mount_path="/etc/pki/tls/certs/ca-bundle.crt",
+                mount_path=CA_BUNDLE_PATH,
                 read_only=True,
                 sub_path="ca-bundle.pem"
             )
@@ -165,7 +170,7 @@ def create_knada_python_pod_operator(
     """
 
     env_vars = {
-        "NOTEBOOK_PATH": f"/repo/{Path(script_path).parent}",
+        "NOTEBOOK_PATH": f"{POD_WORKSPACE_DIR}/{Path(script_path).parent}",
         "NOTEBOOK_NAME": Path(script_path).name,
         "DATAVERK_API_ENDPOINT": os.environ["DATAVERK_API_ENDPOINT"],
         "DATAVERK_BUCKET_ENDPOINT": os.environ["DATAVERK_BUCKET_ENDPOINT"],
@@ -177,7 +182,7 @@ def create_knada_python_pod_operator(
         "VKS_AUTH_PATH": os.environ["VKS_AUTH_PATH"],
         "VKS_KV_PATH": os.environ["VKS_KV_PATH"],
         "K8S_SERVICEACCOUNT_PATH": os.environ["K8S_SERVICEACCOUNT_PATH"],
-        "REQUESTS_CA_BUNDLE": "/etc/pki/tls/certs/ca-bundle.crt"
+        "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH
     }
 
     if extra_envs:
@@ -193,7 +198,7 @@ def create_knada_python_pod_operator(
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
-        init_containers=[create_git_clone_init_container(repo, branch, "/repo")],
+        init_containers=[create_git_clone_init_container(repo, branch, POD_WORKSPACE_DIR)],
         dag=dag,
         on_failure_callback=on_failure,
         startup_timeout_seconds=startup_timeout_seconds,
@@ -205,11 +210,11 @@ def create_knada_python_pod_operator(
         env_vars=env_vars,
         volume_mounts=[
             VolumeMount(
-                name="dags-data", mount_path="/repo", sub_path=None, read_only=False
+                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
             ),
             VolumeMount(
                 name="ca-bundle-pem",
-                mount_path="/etc/pki/tls/certs/ca-bundle.crt",
+                mount_path=CA_BUNDLE_PATH,
                 read_only=True,
                 sub_path="ca-bundle.pem"
             )
@@ -289,9 +294,9 @@ def create_knada_dbt_seed_operator(
 
     return KubernetesPodOperator(
         init_containers=[
-            create_git_clone_init_container(repo, branch, "/repo"),
-            dbt_read_gcs_bucket("/repo", seed_source, dbt_dir) if seed_source["host"] == "gcs" else
-            dbt_read_s3_bucket("/repo", seed_source, dbt_dir),
+            create_git_clone_init_container(repo, branch, POD_WORKSPACE_DIR),
+            dbt_read_gcs_bucket(POD_WORKSPACE_DIR, seed_source, dbt_dir) if seed_source["host"] == "gcs" else
+            dbt_read_s3_bucket(POD_WORKSPACE_DIR, seed_source, dbt_dir),
         ],
         dag=dag,
         on_failure_callback=on_failure,
@@ -302,27 +307,27 @@ def create_knada_dbt_seed_operator(
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_DBT_IMAGE", "navikt/knada-dbt:1"),
         env_vars={
-            "GOOGLE_APPLICATION_CREDENTIALS": "/repo/creds.json",
+            "GOOGLE_APPLICATION_CREDENTIALS": f"{CREDS_DIR}/creds.json",
             "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
             "https_proxy": os.environ["HTTPS_PROXY"],
             "NO_PROXY": os.environ["NO_PROXY"],
             "no_proxy": os.environ["NO_PROXY"],
         },
         cmds=["dbt", "seed"],
-        arguments=["--profiles-dir", f"/repo/{dbt_dir}", "--project-dir", f"/repo/{dbt_dir}"],
+        arguments=["--profiles-dir", f"{POD_WORKSPACE_DIR}/{dbt_dir}", "--project-dir", f"{POD_WORKSPACE_DIR}/{dbt_dir}"],
         volume_mounts=[
             VolumeMount(
-                name="dags-data", mount_path="/repo", sub_path=None, read_only=False
+                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
             ),
             VolumeMount(
                 name="google-creds",
-                mount_path="/repo",
+                mount_path=f"{CREDS_DIR}",
                 sub_path=None,
                 read_only=False,
             ),
             VolumeMount(
                 name="ca-bundle-pem",
-                mount_path="/etc/pki/tls/certs/ca-bundle.crt",
+                mount_path=CA_BUNDLE_PATH,
                 read_only=True,
                 sub_path="ca-bundle.pem"
             ),
@@ -406,7 +411,7 @@ def create_knada_dbt_run_operator(
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
-        init_containers=[create_git_clone_init_container(repo, branch, "/repo")],
+        init_containers=[create_git_clone_init_container(repo, branch, POD_WORKSPACE_DIR)],
         dag=dag,
         on_failure_callback=on_failure,
         startup_timeout_seconds=startup_timeout_seconds,
@@ -416,27 +421,27 @@ def create_knada_dbt_run_operator(
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_DBT_IMAGE", "navikt/knada-dbt:3"),
         env_vars={
-            "GOOGLE_APPLICATION_CREDENTIALS": "/repo/creds.json",
+            "GOOGLE_APPLICATION_CREDENTIALS": f"{CREDS_DIR}/creds.json",
             "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
             "https_proxy": os.environ["HTTPS_PROXY"],
             "NO_PROXY": os.environ["NO_PROXY"],
             "no_proxy": os.environ["NO_PROXY"],
         },
         cmds=["dbt", "run"],
-        arguments=["--profiles-dir", f"/repo/{dbt_dir}", "--project-dir", f"/repo/{dbt_dir}"],
+        arguments=["--profiles-dir", f"{POD_WORKSPACE_DIR}/{dbt_dir}", "--project-dir", f"{POD_WORKSPACE_DIR}/{dbt_dir}"],
         volume_mounts=[
             VolumeMount(
-                name="dags-data", mount_path="/repo", sub_path=None, read_only=False
+                name="dags-data", mount_path=POD_WORKSPACE_DIR, sub_path=None, read_only=False
             ),
             VolumeMount(
                 name="google-creds",
-                mount_path="/repo",
+                mount_path=f"{CREDS_DIR}",
                 sub_path=None,
                 read_only=False,
             ),
             VolumeMount(
                 name="ca-bundle-pem",
-                mount_path="/etc/pki/tls/certs/ca-bundle.crt",
+                mount_path=CA_BUNDLE_PATH,
                 read_only=True,
                 sub_path="ca-bundle.pem"
             ),
@@ -480,12 +485,10 @@ def create_knada_dbt_run_operator(
 def create_knada_bq_operator(
     dag: DAG,
     name: str,
-    repo: str,
     namespace: str,
     bq_cmd: str,
     email: str = None,
     slack_channel: str = None,
-    branch: str = "master",
     resources: dict = None,
     retries: int = 3,
     delete_on_finish: bool = True,
@@ -496,12 +499,10 @@ def create_knada_bq_operator(
 
     :param dag: DAG: owner DAG
     :param name: str: Name of task
-    :param repo: str: Github repo
     :param bq_cmd: list: BigQuery command
     :param namespace: str: K8S namespace for pod
     :param email: str: Email of owner
     :param slack_channel: Name of slack channel, default None (no slack notification)
-    :param branch: str: Branch in repo, default "master"
     :param resources: dict: Specify required cpu and memory requirements (keys in dict: request_memory, request_cpu, limit_memory, limit_cpu), default None
     :param retries: int: Number of retries for task before DAG fails, default 3
     :param delete_on_finish: bool: Whether to delete pod on completion
@@ -520,7 +521,6 @@ def create_knada_bq_operator(
             slack_notification.execute(context)
 
     return KubernetesPodOperator(
-        init_containers=[create_git_clone_init_container(repo, branch, "/repo")],
         dag=dag,
         on_failure_callback=on_failure,
         startup_timeout_seconds=startup_timeout_seconds,
@@ -530,35 +530,33 @@ def create_knada_bq_operator(
         is_delete_operator_pod=delete_on_finish,
         image=os.getenv("KNADA_GCLOUD_IMAGE", "google/cloud-sdk:319.0.0"),
         env_vars={
-            "GOOGLE_APPLICATION_CREDENTIALS": "/repo/creds.json",
+            "GOOGLE_APPLICATION_CREDENTIALS": f"{POD_WORKSPACE_DIR}/creds.json",
             "HTTPS_PROXY": os.environ["HTTPS_PROXY"],
             "https_proxy": os.environ["HTTPS_PROXY"],
             "NO_PROXY": os.environ["NO_PROXY"],
             "no_proxy": os.environ["NO_PROXY"],
-            "REQUESTS_CA_BUNDLE": "/etc/pki/tls/certs/ca-bundle.crt"
+            "REQUESTS_CA_BUNDLE": CA_BUNDLE_PATH
         },
         cmds=["/bin/bash", "-c"],
-        arguments=[f"gcloud auth activate-service-account --key-file=/repo/creds.json; {bq_cmd}"],
+        arguments=[f"gcloud config set core/custom_ca_certs_file {CA_BUNDLE_PATH}; "
+                   f"gcloud auth activate-service-account --key-file={CREDS_DIR}/creds.json; "
+                   f"{bq_cmd}"],
         volume_mounts=[
-            VolumeMount(
-                name="dags-data", mount_path="/repo", sub_path=None, read_only=False
-            ),
             VolumeMount(
                 name="google-creds",
-                mount_path="/repo",
+                mount_path=CREDS_DIR,
                 sub_path=None,
                 read_only=False,
             ),
             VolumeMount(
                 name="ca-bundle-pem",
-                mount_path="/etc/pki/tls/certs/ca-bundle.crt",
+                mount_path=CA_BUNDLE_PATH,
                 read_only=True,
                 sub_path="ca-bundle.pem"
             ),
         ],
         service_account_name="airflow",
         volumes=[
-            Volume(name="dags-data", configs={}),
             Volume(name="ca-bundle-pem",
                    configs={
                         "configMap": {
